@@ -79,8 +79,6 @@ def constraints_to_sql(
     else:
         raise Exception("Invalid constraint type")
 
-
-
     return constraint_list_to_sql(
         constraint_list,
         paren=paren,
@@ -233,21 +231,24 @@ def update_sql(
     :param timestamp_col: the 'updated_at' column, if any
     :param returning: the list of colums to return from the update statement
     """
-    if timestamp_col and assignments:
-        if isinstance(assignments, TextConstraint):
-            raise Exception(
-                "Cannot combine timestamp_col and TextConstraint for update"
-            )
+    if timestamp_col:
+        if assignments:
+            if isinstance(assignments, TextConstraint):
+                raise Exception(
+                    "Cannot combine timestamp_col and TextConstraint for update"
+                )
 
-        if isinstance(assignments, DictConstraint):
-            assignments[timestamp_col] = Literal("now()")
-        elif isinstance(assignments, BinaryConstraint):
-            assignments = [
-                assignments,
-                BinaryConstraint(timestamp_col, Literal("now()")),
-            ]
+            if isinstance(assignments, DictConstraint):
+                assignments[timestamp_col] = Literal("now()")
+            elif isinstance(assignments, BinaryConstraint):
+                assignments = [
+                    assignments,
+                    BinaryConstraint(timestamp_col, Literal("now()")),
+                ]
+            else:
+                assignments.append(BinaryConstraint(timestamp_col, Literal("now()")))
         else:
-            assignments.append(BinaryConstraint(timestamp_col, Literal("now()")))
+            assignments = [BinaryConstraint(timestamp_col, Literal("now()"))]
 
     (assign_sql, assign_params) = constraints_to_sql(
         assignments, paren=False, joiner=", ", handle_null=False
@@ -256,6 +257,9 @@ def update_sql(
         constraints, paren=True, offset=len(assign_params)
     )
 
+    if not assign_sql:
+        raise Exception("No assigments given for update")
+
     sql = "update {} set {}".format(table_name, assign_sql)
 
     if constraint_sql:
